@@ -356,7 +356,7 @@ def mmphi(X: np.ndarray, q: Optional[float] = 2.0, p: Optional[float] = 1.0) ->
         >>> # Calculate the space-fillingness metric with q=2, using Euclidean distances (p=2)
         >>> quality = mmphi(X, q=2, p=2)
         >>> print(quality)
-        # This value indicates how well points are spread out, with higher being better.
+        # This value indicates how well points are spread out, with smaller being better.
     """
     # Compute the distance multiplicities: J, and unique distances: d
     J, d = jd(X, p)
@@ -558,7 +558,7 @@ def mmlhs(X_start: np.ndarray, population: int, iterations: int, q: Optional[flo
 
     Examples:
         >>> import numpy as np
-        >>> from your_module import mmlhs
+        >>> from spotpython.utils.sampling import mmlhs
         >>> # Suppose we have an initial 4x2 plan
         >>> X_start = np.array([
         ...     [0, 0],
@@ -620,7 +620,7 @@ def mmlhs(X_start: np.ndarray, population: int, iterations: int, q: Optional[flo
     return X_best
 
 
-def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, verbosity=0, edges=0) -> np.ndarray:
+def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, verbosity=0, edges=0, q_list=[1, 2, 5, 10, 20, 50, 100]) -> np.ndarray:
     """
     Generates an optimized Latin hypercube by evolving the Morris-Mitchell
     criterion across multiple exponents (q values) and selecting the best plan.
@@ -646,6 +646,10 @@ def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, ve
             If 1, places centers of the extreme bins at the domain edges ([0,1]).
             Otherwise, bins are fully contained within the domain, i.e. midpoints.
             Defaults to 0.
+        q_list (list, optional):
+            A list of q values to optimize. Defaults to [1, 2, 5, 10, 20, 50, 100].
+            These values are used to evaluate the space-fillingness of the Latin
+            hypercube. The best plan is selected based on the lowest mmphi value.
 
     Returns:
         np.ndarray:
@@ -676,7 +680,6 @@ def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, ve
         raise ValueError("Latin hypercubes are not defined for dim k < 2")
 
     # A list of exponents (q) to optimize
-    q_list = [1, 2, 5, 10, 20, 50, 100]
 
     # Start with a random Latin hypercube
     X_start = rlh(n, k, edges=edges)
@@ -708,6 +711,7 @@ def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, ve
         plt.title(f"Morris-Mitchell optimum plan found using q={q_list[best_idx]}")
         plt.xlabel("x_1")
         plt.ylabel("x_2")
+        plt.grid(True)
         plt.show()
 
     return X
